@@ -142,15 +142,15 @@ panelLegend <- function(method=c("boxplot", "lines"), type, pch,
 mayplot <- function(x, vList, row.vars = NULL, col.vars = NULL, xvar,
                     method = if(has.n.sim) "boxplot" else "lines",
                     panel.first = NULL, panel.last = NULL,
-                    type = "l", pch = NULL,  ylim = "global",
-                    log = "", do.legend = TRUE,
+                    type = "l", pch = NULL, ylim = "global",
+                    log = "", main = "", do.legend = TRUE,
 		    spc = c(0.04/max(1,n.x-1), 0.04/max(1,n.y-1)),
-                    axlabspc = c(0.12, 0.08), labspc = c(0.04, 0.04),
-                    n.sim.spc = 0.06,
+                    axlabspc = c(0.12, 0.11), labspc = c(0.04, 0.04), mainspc = 0.08,
+                    legendspc = 0.03, n.sim.spc = 0.06,
                     auxcol = c("gray40", "gray78", "gray90", "white"),
 		    pcol = c("black", "blue", "red", "orange"), grid.lwd=1.6, ax.lwd=2,
-		    tx.cex = 1.2, leg.cex = 1, xlab = NULL, ylab = NA,
-                    do.n.sim = has.n.sim,
+		    tx.cex = 1.2, leg.cex = 1, main.cex = 1.3,
+                    xlab = NULL, xlab.line = 2.4, ylab = NA, do.n.sim = has.n.sim,
 		    verbose = getOption("verbose"), show.layout = verbose, ...)
 {
     ## basics ##################################################################
@@ -246,7 +246,7 @@ mayplot <- function(x, vList, row.vars = NULL, col.vars = NULL, xvar,
 	if(!do.ylim) ylim <- range(x, na.rm=TRUE)
     } else if(is.numeric(ylim)) {
 	do.ylim <- FALSE
-	if(!(length(ylim) == 2 && is.finite(ylim)))
+	if(!(length(ylim) == 2 && all(is.finite(ylim))))
 	    stop(ylim.msg)
     } else stop(ylim.msg)
 
@@ -282,11 +282,14 @@ mayplot <- function(x, vList, row.vars = NULL, col.vars = NULL, xvar,
     ## legend
     if(do.legend) {
         legend.grob <- pl$legend
-        legspc <- 0.03 ### FIXME from grob! (and test with cex=0.5 or 2,etc)
-    }
+    } else legendspc <- 0
+    ## main
+    do.main <- main != ""
+    if(!do.main) mainspc <- 0
 
     stopifnot(length(spc) == 2, length(axlabspc) == 2,
-	      length(labspc) == 2, length(auxcol) == 4)
+	      length(labspc) == 2, length(auxcol) == 4,
+              length(mainspc) == 1)
 
     ## number of columns/rows in the layout
     ## for y axis label; (nx-1)* (plot+gaps); plot; row.vars labels :
@@ -301,14 +304,14 @@ mayplot <- function(x, vList, row.vars = NULL, col.vars = NULL, xvar,
     nx. <- length(wid.gl) # number of columns in the layout
     ## for col.vars labels; (ny-1)*(plot+gap); plot;
     ## space for 1 (of n.y) plot in y direction:
-    leg.spc <- if(do.legend) legspc else 0
-    h.all <- (labspc[2] + axlabspc[2] + leg.spc + (n.y-1)*spc[2])
-    if(h.all >= 1) stop("Choose smaller 'xlabspc[2]', 'labspc[2]', 'spc[2]', 'legspc'")
-    Pysp <- (1 - h.all) / n.y
-    hei.gl <- c(labspc[2], # panel labels
+    h.all <- mainspc + labspc[2] + axlabspc[2] + legendspc + (n.y-1) * spc[2]
+    if(h.all >= 1) stop("Choose smaller 'xlabspc[2]', 'labspc[2]', 'spc[2]', 'legendspc'")
+    Pysp <- (1 - h.all) / n.y # y-space of each panel
+    hei.gl <- c(if(do.main) mainspc, # vertical space for title
+                labspc[2], # panel labels
                 rep(c(Pysp, spc[2]), n.y-1), Pysp, # panels (+ vertical space in between)
                 axlabspc[2], # x axis label
-		if(do.legend) leg.spc) # legend
+		if(do.legend) legendspc) # legend
     ny. <- length(hei.gl) # number of rows in the layout
 
 
@@ -333,7 +336,7 @@ mayplot <- function(x, vList, row.vars = NULL, col.vars = NULL, xvar,
     ## walk over rows
     for(i in 1:n.y)
     {
-        i. <- 2*i # column index in layout (for jumping over gaps)
+        i. <- if(do.main) 2*i+1 else 2*i # row index in layout (for jumping over gaps)
 	if(verbose) cat(sprintf("plot row %d (%d): [columns:] ", i, i.))
         ## pick out data to plot
 	xi <- # x for a fixed 'i'
@@ -351,7 +354,7 @@ mayplot <- function(x, vList, row.vars = NULL, col.vars = NULL, xvar,
         ## walk over columns
 	for(j in 1:n.x)
         {
-	    j. <- 2*j # row index in layout (for jumping over gaps)
+	    j. <- 2*j # column index in layout (for jumping over gaps)
 	    if(verbose) cat(sprintf("%d (%d) ", j, j.))
 
             ## push viewport
@@ -417,7 +420,8 @@ mayplot <- function(x, vList, row.vars = NULL, col.vars = NULL, xvar,
 			 lwd=ax.lwd, col=NA, col.ticks=c.ax, col.axis=c.ax)
 		else
 		    axis(1, lwd=ax.lwd, col=NA, col.ticks=c.ax, col.axis=c.ax)
-                if(is.null(xlab)) xlab <- vList[[xvar]]$expr
+                if(is.null(xlab))
+                    xlab <- vList[[xvar]]$expr
 		if(!identical(xlab, NA)) { # x axis label
 		    ## would need "with local viewport": but the push..()/up..()
 		    ## does not work  WHY ???
@@ -429,10 +433,14 @@ mayplot <- function(x, vList, row.vars = NULL, col.vars = NULL, xvar,
 		    ## Using traditional graphics instead:
 		    ## mtext(xlab, side=1, at=zrange[2], col = c.ax, adj=c(0,0))
 		    ## ... TODO MM ... use grid!  This *IS* ugly
-		    ## draw it between the last two tick marks :
-		    axt <- axTicks(1)
-		    at <- mean(axt[-1:0 + length(axt)])
-		    mtext(xlab, side=1, at=at, col = c.ax, font = 2)#, adj=0.5
+                    ##
+		    ## OLD CODE: draw it between the last two tick marks :
+		    ## axt <- axTicks(1)
+		    ## at <- mean(axt[-1:0 + length(axt)])
+		    ## mtext(xlab, side=1, at=at, col = c.ax, font = 2)
+                    ## NEW CODE:
+		    mtext(xlab, side = 1, line = xlab.line, col = c.ax, font = 1)
+                    ## VERY OLD:
 		    ## draw axis arrow  '-->'  above the xlab:
 		    ## pu <- par("usr"); if(par("xlog")) pu[1:2] <- 10^pu[1:2]
 		    ## x0 <- pu[2] + (pu[2]-pu[1])
@@ -458,8 +466,9 @@ mayplot <- function(x, vList, row.vars = NULL, col.vars = NULL, xvar,
             ## panel labels ####################################################
 
 	    ## column (col.vars) panel labels
-	    if(i == 1 && !is.null(col.vars)) {
-		pushViewport(viewport(layout.pos.row=1, layout.pos.col=j.))
+            ii <- if(do.main) 2 else 1
+	    if(i == ii && !is.null(col.vars)) {
+		pushViewport(viewport(layout.pos.row=ii, layout.pos.col=j.))
 		grid.rect(gp=gpar(col=NA, fill=auxcol[2]))
 		grid.text(tryExpr(dn[[col.vars]][j]), x=0.5, y=0.5, gp=gpar(cex=tx.cex))
 		popViewport()
@@ -486,19 +495,20 @@ mayplot <- function(x, vList, row.vars = NULL, col.vars = NULL, xvar,
     ## ylab
     if(!identical(ylab, NA)) { # may be language where is.na(.) warns
 	max.row <- if(lv) ny.-2 else ny.-1
-	stopifnot(max.row >= 2) # defensive programming
+        row.ran <- if(do.main) 3:max.row else 2:max.row
         ## main
-	pushViewport(viewport(layout.pos.row=2:max.row, layout.pos.col=1))
-	grid.text(ylab, x=unit(0.6, "lines"), just=c("left", "centre"), rot=90)
+	pushViewport(viewport(layout.pos.row=row.ran, layout.pos.col=1))
+	grid.text(ylab, x=unit(0.6, "lines"), just=c("centre", "centre"), rot=90) # used to be c("left", "centre") for a while, but doesn't make sense
 	popViewport()
     }
 
     ## ylab2 (n.sim)
     if(has.n.sim && do.n.sim) {
 	max.row <- if(lv) ny.-2 else ny.-1
-	stopifnot(max.row >= 2) # defensive programming
+        row.ran <- 2:max.row
+        row.ran <- if(do.main) 3:max.row else 2:max.row
         ## main
-	pushViewport(viewport(layout.pos.row=2:max.row, layout.pos.col=nx.))
+	pushViewport(viewport(layout.pos.row=row.ran, layout.pos.col=nx.))
         ## note: vLnsim = vList[["n.sim"]] (which is defined if has.n.sim)
         lab <- substitute(lab == val, list(lab=vLnsim[["expr"]], val=vLnsim[["value"]]))
 	grid.text(lab, y=unit(0, "npc"), # placing it at last/bottom panel(s)
@@ -508,14 +518,22 @@ mayplot <- function(x, vList, row.vars = NULL, col.vars = NULL, xvar,
     }
 
     ## legend (for all variables appearing in a single panel)
-    if(do.legend)
-    {
-        ## main
+    if(do.legend) {
         wran <- if(has.n.sim) 2:(nx.-2) else 2:(nx.-1) # width range
 	pushViewport(viewport(layout.pos.row=ny., layout.pos.col=wran))
         grid.draw(legend.grob)
         popViewport()
     }
+
+    ## main
+    if(do.main) {
+        wran <- if(has.n.sim) 2:(nx.-2) else 2:(nx.-1) # width range
+	pushViewport(viewport(layout.pos.row=1, layout.pos.col=wran))
+        grid.text(main, x=0.5, y=0.5, gp=gpar(cex=main.cex))
+        popViewport()
+    }
+
+    ## Return
     invisible(gl)
 }
 ##' { end } mayplot
